﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Interactivity;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Menus;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = TreeData.GenerateTreeData();
        }
    }

    public class MyCommand : ICommand
    {
        public bool CanExecute(object parameter)
        {
            return true;
        }

        public event EventHandler CanExecuteChanged;

        public void Execute(object parameter)
        {

            if ((parameter as XamDataTreeNode).Control.Content.ToString() == "Item 1"
                || (parameter as XamDataTreeNode).Control.Content.ToString() == "Item 2"
                || (parameter as XamDataTreeNode).Control.Content.ToString() == "Item 3")
            {
                (parameter as XamDataTreeNode).IsChecked = false;
            }
            else
            {
                foreach (var item in (parameter as XamDataTreeNode).Nodes)
                {
                    item.IsChecked = (parameter as XamDataTreeNode).IsChecked;
                }
            }
        }
    }

    public class NodeCheckedChangedBehavior : Behavior<XamDataTree>
    {

        public ICommand NodeCheckedChangedCommand
        {
            get { return (ICommand)GetValue(NodeCheckedChangedCommandProperty); }
            set { SetValue(NodeCheckedChangedCommandProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Command.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty NodeCheckedChangedCommandProperty =
            DependencyProperty.Register("NodeCheckedChangedCommand", typeof(ICommand), typeof(NodeCheckedChangedBehavior), new PropertyMetadata(null));

        protected override void OnAttached()
        {
            base.OnAttached();
            AssociatedObject.NodeCheckedChanged += AssociatedObject_NodeCheckedChanged;
        }

        void AssociatedObject_NodeCheckedChanged(object sender, NodeEventArgs e)
        {
            AssociatedObject.NodeCheckedChanged -= AssociatedObject_NodeCheckedChanged;

            if (NodeCheckedChangedCommand != null)
                NodeCheckedChangedCommand.Execute(e.Node);

            AssociatedObject.NodeCheckedChanged += AssociatedObject_NodeCheckedChanged;
        }
    }
    
    public class TreeData : PropertyChangedNotifier
    {
        private int id;

        public int ID
        {
            get { return id; }
            set { id = value; OnPropertyChagned("ID"); }
        }

        private string name;

        public string Name
        {
            get { return name; }
            set { name = value; OnPropertyChagned("Name"); }
        }

        private ObservableCollection<TreeData> children;

        public ObservableCollection<TreeData> Children
        {
            get { return children; }
            set { children = value; OnPropertyChagned("Children"); }
        }

        public static ObservableCollection<TreeData> GenerateTreeData()
        {
            ObservableCollection<TreeData> data = new ObservableCollection<TreeData>();

            for (int i = 0; i < 10; i++)
            {
                TreeData n = new TreeData
                {
                    ID = i,
                    Name = "Item " + i,
                    Children = new ObservableCollection<TreeData>()
                };

                for (int j = 0; j < 5; j++)
                {
                    TreeData n1 = new TreeData
                    {
                        ID = i + j,
                        Name = "Item " + i + " " + j,
                        Children = new ObservableCollection<TreeData>()
                    };

                    for (int p = 0; p < 5; p++)
                    {
                        n1.children.Add(new TreeData
                        {
                            ID = i + j + p,
                            Name = "Item " + i + " " + j + " " + p,
                        });
                    }

                    n.Children.Add(n1);
                }

                data.Add(n);
            }

            return data;
        }

    }

    public class PropertyChangedNotifier : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        public void OnPropertyChagned(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }	
				
}
